
[//]: # (<p align="center">)

[//]: # (   <a href="https://github.com/durandtibo/meteor/actions">)

[//]: # (      <img alt="CI" src="https://github.com/durandtibo/meteor/workflows/CI/badge.svg?event=push&branch=main">)

[//]: # (   </a>)

[//]: # (    <a href="https://pypi.org/project/gravitorch/">)

[//]: # (      <img alt="PYPI version" src="https://img.shields.io/pypi/v/gravitorch">)

[//]: # (    </a>)

[//]: # (   <a href="https://pypi.org/project/gravitorch/">)

[//]: # (      <img alt="Python" src="https://img.shields.io/pypi/pyversions/gravitorch.svg">)

[//]: # (   </a>)

[//]: # (   <a href="https://opensource.org/licenses/BSD-3-Clause">)

[//]: # (      <img alt="BSD-3-Clause" src="https://img.shields.io/pypi/l/gravitorch">)

[//]: # (   </a>)

[//]: # (   <a href="https://codecov.io/gh/durandtibo/meteor">)

[//]: # (      <img alt="Codecov" src="https://codecov.io/gh/durandtibo/meteor/branch/main/graph/badge.svg">)

[//]: # (   </a>)

[//]: # (   <a href="https://github.com/psf/black">)

[//]: # (     <img  alt="Code style: black" src="https://img.shields.io/badge/code%20style-black-000000.svg">)

[//]: # (   </a>)

[//]: # (   <a href="https://google.github.io/styleguide/pyguide.html#s3.8-comments-and-docstrings">)

[//]: # (     <img  alt="Doc style: google" src="https://img.shields.io/badge/%20style-google-3666d6.svg">)

[//]: # (   </a>)

[//]: # (   <br/>)

[//]: # (</p>)


<p align="center">
   <a>
      <img alt="CI" src="https://github.com/durandtibo/meteor/workflows/CI/badge.svg?event=push&branch=main">
   </a>
    <a href="https://pypi.org/project/gravitorch/">
      <img alt="PYPI version" src="https://img.shields.io/pypi/v/gravitorch">
    </a>
   <a href="https://pypi.org/project/gravitorch/">
      <img alt="Python" src="https://img.shields.io/pypi/pyversions/gravitorch.svg">
   </a>
   <a href="https://opensource.org/licenses/BSD-3-Clause">
      <img alt="BSD-3-Clause" src="https://img.shields.io/pypi/l/gravitorch">
   </a>
   <a>
      <img alt="Codecov" src="https://codecov.io/gh/durandtibo/meteor/branch/main/graph/badge.svg">
   </a>
   <a href="https://github.com/psf/black">
     <img  alt="Code style: black" src="https://img.shields.io/badge/code%20style-black-000000.svg">
   </a>
   <a href="https://google.github.io/styleguide/pyguide.html#s3.8-comments-and-docstrings">
     <img  alt="Doc style: google" src="https://img.shields.io/badge/%20style-google-3666d6.svg">
   </a>
   <br/>
</p>
